/**
 * NOTE: THIS IS A GENERATED FILE. PLEASE CONSULT THE ORIGINAL IDL FILE
 * FOR THE FULL DOCUMENTION AND LICENSE.
 *
 * @see <a href="http://lxr.mozilla.org/mozilla/search?string=interface+nsIDataChannel">
 **/

package org.mozilla.xpcom;

public interface nsIDataChannel extends nsIChannel
{
  public static final String NS_IDATACHANNEL_IID =
    "{7e835f60-5fea-11d3-a177-0050041caf44}";

}
